<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Будь ласка, увійдіть до вашого облікового запису Deepin.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Для виконання наступних дій вам слід увійти до системи.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Вами надіслано надто багато запитів. Будь ласка, повторіть спробу пізніше.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Для виконання наступних дій вам слід увійти до системи.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Помилка у мережі. Будь ласка, повторіть спробу.</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Поза системою</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Улюблене</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Відгуки</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Увійти</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 переглядів</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Пропозиції</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити з улюблених</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Додати до улюблених</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Скасувати критичність</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Зробити критичним</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Невдовзі</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Офіційна відповідь</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Усі</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Вада</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Пропозиції</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Версія:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Упорядкування:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Найновіші</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Улюблені</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Критичні</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Спілкування</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Тут можна обговорювати і ділитися враженнями</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Звіт щодо вади</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Повідомте про виявлені вади</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Пропозиції</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Надішліть ваші пропозиції</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Ресурси</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Опитування</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Долучіться до нас</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Внутрішнє тестування</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Community News</source>
        <translation>Новини спільноти</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>Більше записів немає</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Повідомлення</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Опитування</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Запускати при запуску системи</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Домівка Deepin</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Швидке входження на форуми, сторінки надсилання пропозицій та повідомлення про вади.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Ще немає повідомлень.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 повідомлень</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Позначити усі як прочитані</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Переглянути ще</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Помилка у мережі. Будь ласка, повторіть спробу</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Освіжити</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Домівка Deepin</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Ще немає опитувань.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Строк дії: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Заповнення</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>У черзі</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Відтворюваність</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Підтверджено</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Надано відповідь</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Розв&apos;язано</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>Оцінка</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Прийнято</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Завершено</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>Запис вади не було оброблено, і його не буде показано у загальнодоступному списку.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Зараз неможливо визначити причину; потрібне неперервне спостереження та вивчення.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>Ваду вдалося відтворити, а основну причину визначено.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>Проблема не є вадою або має іншу природу.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>Проблему розв&apos;язано, вона очікує на формальний випуск</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>Запис вимоги не було оброблено, і його не буде показано у загальнодоступному списку.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>Проблему усвідомлено, триває внутрішня оцінка</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Включено до планів щодо майбутнього випуску</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>Вимогу або не прийнято, або її неможливо обробити</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>Розробку завершено, очікуємо на формальний вираз</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>Не вдалося додати знімок вікна.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>Розмір файла зображення має бути меншим за 1 МБ.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>Не передбачено підтримки вивантаження файлів зображень у цьому форматі.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Поточний стан продукту]: 
[Бажаний продукт]: </translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Попередні умови]: 
[Кроки відтворення]: 
[Очікувані результати]: 
[Поточні результати]: </translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Надіслати відгук</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Пропозиції</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Звіт щодо вади</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Заголовок:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Будь ласка, надайте короткий опис вашої проблеми</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Вміст:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Не поєднуйте декілька проблем в одному відгуку</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Не вписуйте декілька вимог до одного відгуку</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>Адреса ел. пошти:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Будь ласка, введіть вашу адресу ел. пошти</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Версія системи:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Дані щодо пристрою:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Вивантажити &lt;a href=&apos;home://sysinfo&apos;&gt;дані щодо пристрою&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Знімки вікон:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Файли зображень</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Перетягніть і скиньте файли або натисніть кнопку додавання зображень у кількості до трьох</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Ви справді хочете перервати надсилання відгуку?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>Вміст відгуку не буде збережено.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Надіслати</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>Не вдалося надіслати відгук.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Будь ласка, надайте заголовок та дані вашого відгуку.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Будь ласка, надайте заголовок вашого відгуку.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Будь ласка, надайте дані вашого відгуку.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Введено некоректну адресу електронної пошти.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Дані щодо пристрою</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Вузол відгуків</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Відгуки</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Улюблене</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>Критичне</translation>
    </message>
</context>
</TS>